Title: [224621] trunk/Source/WebInspectorUI
Revision
224621
Author
commit-qu...@webkit.org
Date
2017-11-09 00:12:04 -0800 (Thu, 09 Nov 2017)

Log Message

REGRESSION(r224566): [GTK][WPE] Many inspector tests are failing after r224566
https://bugs.webkit.org/show_bug.cgi?id=179419

Patch by Carlos Garcia Campos <cgar...@igalia.com> on 2017-11-09
Reviewed by Carlos Alberto Lopez Perez.

All of them fail with the following error:

Uncaught exception in Inspector page: ReferenceError: Can't find variable: CodeMirror [TestCombined.js:36658:15]

This is because Test.html, even when combined, is trying to load CodeMirror from External/CodeMirror, but
CodeMirror was already combined for Main.html. We need to also combine CodeMirror for Test.html.

* Scripts/copy-user-interface-resources.pl:

Modified Paths

Diff

Modified: trunk/Source/WebInspectorUI/ChangeLog (224620 => 224621)


--- trunk/Source/WebInspectorUI/ChangeLog	2017-11-09 07:59:31 UTC (rev 224620)
+++ trunk/Source/WebInspectorUI/ChangeLog	2017-11-09 08:12:04 UTC (rev 224621)
@@ -1,3 +1,19 @@
+2017-11-09  Carlos Garcia Campos  <cgar...@igalia.com>
+
+        REGRESSION(r224566): [GTK][WPE] Many inspector tests are failing after r224566
+        https://bugs.webkit.org/show_bug.cgi?id=179419
+
+        Reviewed by Carlos Alberto Lopez Perez.
+
+        All of them fail with the following error:
+
+        Uncaught exception in Inspector page: ReferenceError: Can't find variable: CodeMirror [TestCombined.js:36658:15]
+
+        This is because Test.html, even when combined, is trying to load CodeMirror from External/CodeMirror, but
+        CodeMirror was already combined for Main.html. We need to also combine CodeMirror for Test.html.
+
+        * Scripts/copy-user-interface-resources.pl:
+
 2017-11-08  Joseph Pecoraro  <pecor...@apple.com>
 
         Web Inspector: Show Internal properties of PaymentRequest in Web Inspector Console

Modified: trunk/Source/WebInspectorUI/Scripts/copy-user-interface-resources.pl (224620 => 224621)


--- trunk/Source/WebInspectorUI/Scripts/copy-user-interface-resources.pl	2017-11-09 07:59:31 UTC (rev 224620)
+++ trunk/Source/WebInspectorUI/Scripts/copy-user-interface-resources.pl	2017-11-09 08:12:04 UTC (rev 224621)
@@ -335,8 +335,17 @@
 
     my $derivedSourcesTestHTML = File::Spec->catfile($derivedSourcesDir, 'Test.html');
     my $derivedSourcesTestJS = File::Spec->catfile($derivedSourcesDir, 'TestCombined.js');
     # Combine the Esprima _javascript_ files for testing into a single file (Esprima.js).
     system($perl, $combineResourcesCmd,
+        '--input-dir', 'External/CodeMirror',
+        '--input-html', $derivedSourcesTestHTML,
+        '--input-html-dir', $uiRoot,
+        '--derived-sources-dir', $derivedSourcesDir,
+        '--output-dir', $derivedSourcesDir,
+        '--output-script-name', 'TestCodeMirror.js');
+
+    # Combine the Esprima _javascript_ files for testing into a single file (TestEsprima.js).
+    system($perl, $combineResourcesCmd,
         '--input-dir', 'External/Esprima',
         '--input-html', $derivedSourcesTestHTML,
         '--input-html-dir', $uiRoot,
@@ -348,7 +357,11 @@
     my $targetTestJS = File::Spec->catfile($targetResourcePath, 'TestCombined.js');
     seedFile($targetTestJS, $inspectorLicense);
 
-    # Export the license into Esprima.js.
+    # Export the license into TestCodeMirror.js.
+    my $targetCodeMirrorJS = File::Spec->catfile($targetResourcePath, 'TestCodeMirror.js');
+    seedFile($targetCodeMirrorJS, $codeMirrorLicense);
+
+    # Export the license into TestEsprima.js.
     my $targetEsprimaJS = File::Spec->catfile($targetResourcePath, 'TestEsprima.js');
     seedFile($targetEsprimaJS, $esprimaLicense);
 
@@ -355,6 +368,10 @@
     # Append TestCombined.js to the license that was exported above.
     appendFile($targetTestJS, $derivedSourcesTestJS);
 
+    # Append CodeMirror.js to the license that was exported above.
+    my $derivedSourcesCodeMirrorJS = File::Spec->catfile($derivedSourcesDir, 'TestCodeMirror.js');
+    appendFile($targetCodeMirrorJS, $derivedSourcesCodeMirrorJS);
+
     # Append Esprima.js to the license that was exported above.
     my $derivedSourcesEsprimaJS = File::Spec->catfile($derivedSourcesDir, 'TestEsprima.js');
     appendFile($targetEsprimaJS, $derivedSourcesEsprimaJS);
@@ -335,8 +335,17 @@
     my $derivedSourcesTestHTML = File::Spec->catfile($derivedSourcesDir, 'Test.html');
     my $derivedSourcesTestJS = File::Spec->catfile($derivedSourcesDir, 'TestCombined.js');
-    # Combine the Esprima _javascript_ files for testing into a single file (Esprima.js).
+    # Combine the CodeMirror _javascript_ files into single file (TestCodeMirror.js).
     system($perl, $combineResourcesCmd,
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to